#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 here
version:              1.2.14
visibility:           public
id:                   here-1.2.14-IhI4LsgXl263mNSojUZ3Ox
key:                  here-1.2.14-IhI4LsgXl263mNSojUZ3Ox
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  d76373c3f289626ce0f9336212bceb92
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs:         /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/here-1.2.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-here
hs-libraries:         HShere-1.2.14-IhI4LsgXl263mNSojUZ3Ox
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-AuUF6YQhesCAAhCBxjByUC
    mtl-2.3.1 parsec-3.1.16.1 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

